/*
  Copyright 2002 Massachusetts Institute of Technology
    
  Permission to use, copy, modify, and distribute this program for any
  purpose and without fee is hereby granted, provided that this
  copyright and permission notice appear on all copies and supporting
  documentation, the name of M.I.T. not be used in advertising or
  publicity pertaining to distribution of the program without specific
  prior permission, and notice be given in supporting documentation that
  copying and distribution is by permission of M.I.T.  M.I.T. makes no
  representations about the suitability of this software for any
  purpose.  It is provided "as is" without express or implied warranty.
*/
package sdsi;
import sdsi.*;
import sdsi.sexp.*;
import java.security.NoSuchAlgorithmException;

/**
   @author Alexander Morcos, Sameer Ajmani
**/
class HashOp extends Op {
    public static String OPCODE = "hash";
    HashOp(SexpList l) throws SexpParseException
    {
	super(l);
	if (!l.getType().equals("do"))
	    throw new SexpParseException("Not an Op");
	if ((l.size() < 2) || !(l.elementAt(1) instanceof SexpString))
	    throw new SexpParseException("Op type not specified");
	if (!getOpcode().equals(OPCODE))
	    throw new SexpParseException("Not a hash Op");
	if ((l.size() < 3) || !(l.elementAt(2) instanceof SexpString))
	    throw new SexpParseException("Hash algorithm not specified");
	if (l.size() > 3)
	    throw new SexpParseException("Too many items in list");
    }
    public static HashOp create(String algo) throws SDSIException
    {
	try {
	    return new HashOp(new SexpList(new Sexp[] {
		new SexpString("do"), new SexpString(OPCODE),
		    new SexpString(algo) }));
	} catch (SexpParseException e) {
	    throw new SDSIException("SexpParseException: "+e.getMessage());
	}
    }
    public String getAlgorithm()
    {
	return ((SexpString)srep.elementAt(2)).stringContent();
    }
    public Hash execute(SDSIObject object) throws NoSuchAlgorithmException
    {
	return new Hash(getAlgorithm(), object);
    }
}
