/*
  Copyright 2002 Massachusetts Institute of Technology
    
  Permission to use, copy, modify, and distribute this program for any
  purpose and without fee is hereby granted, provided that this
  copyright and permission notice appear on all copies and supporting
  documentation, the name of M.I.T. not be used in advertising or
  publicity pertaining to distribution of the program without specific
  prior permission, and notice be given in supporting documentation that
  copying and distribution is by permission of M.I.T.  M.I.T. makes no
  representations about the suitability of this software for any
  purpose.  It is provided "as is" without express or implied warranty.
*/
package sdsi;

import sdsi.sexp.*;

/**
   @author Alexander Morcos, Sameer Ajmani
**/
public class KeyHolder extends SDSIObject implements Subject{
  SDSIPrincipal creatingPrincipal;  //may not need to carry this around
  //may only need for creation
  public KeyHolder(SexpList l,SDSIPrincipal p) throws SexpParseException {
    super(l);
    creatingPrincipal = p;
    if (!l.getType().equals("keyholder"))
      throw new SexpParseException("Not a keyholder");
    if (!(l.size() == 2) || !(l.elementAt(1) instanceof SexpList))
      throw new SexpParseException("Incorrectly formatted keyholder");
    SDSIObject supposedHolder = SDSIObject.principalParse((SexpList)l.elementAt(1),creatingPrincipal);
    if (!(supposedHolder instanceof SDSIPrincipal) && !(supposedHolder instanceof Name))
      throw new SexpParseException("Keyholder must be a principal or a name");
  }
  public SDSIObject getObject() {
    try {
      return SDSIObject.principalParse((SexpList)srep.elementAt(1),creatingPrincipal);
    }
    catch (SexpParseException e) {
      return null;
    }
  }
  public String toShortString() {
    return "k_h " + this.getObject().toShortString();
  }
    public String getAbbreviation()
    {
	return "Kh";
    }
}  
