/*
  Copyright 2002 Massachusetts Institute of Technology
    
  Permission to use, copy, modify, and distribute this program for any
  purpose and without fee is hereby granted, provided that this
  copyright and permission notice appear on all copies and supporting
  documentation, the name of M.I.T. not be used in advertising or
  publicity pertaining to distribution of the program without specific
  prior permission, and notice be given in supporting documentation that
  copying and distribution is by permission of M.I.T.  M.I.T. makes no
  representations about the suitability of this software for any
  purpose.  It is provided "as is" without express or implied warranty.
*/
package sdsi;

import sdsi.sexp.*;

/**
   @author Alexander Morcos, Sameer Ajmani
**/
public class ObjectHash extends SDSIObject implements Subject{
    private Hash _hashOfObject = null;
    public ObjectHash(SexpList l) throws SexpParseException
    {
	super(l);
	if (!l.getType().equals("object-hash"))
	    throw new SexpParseException("Not a object hash");
	if (!(l.size() == 2) || !(l.elementAt(1) instanceof SexpList))
	    throw new SexpParseException("Incorrectly formatted object hash");
	SDSIObject object =
	    SDSIObject.principalParse((SexpList)srep.elementAt(1), null);
	if (!(object instanceof Hash))
	    throw new SexpParseException("Object hash must be a hash");
	_hashOfObject = (Hash)object;
    }
    // FIXME: this should only have package visibility
    public ObjectHash(Hash hash) throws SexpParseException
    {
	this(new SexpList(new Sexp[] { new SexpString("object-hash"),
					   hash.getSrep() }));
    }
    // use this factory outside of the package
    public static ObjectHash create(Hash hash) throws SDSIException
    {
	try {
	    return new ObjectHash(hash);
	} catch (SexpParseException e) {
	    throw new SDSIException("Internal Error: SexpParseException: "
				    +e.getMessage());
	}
    }

    public Hash getHashOfObject()
    {
	return _hashOfObject;
    }
    public String toShortString()
    {
	return "Obj " + _hashOfObject.toShortString();
    }
    public String getType()
    {
	return "Object Hash";
    }
    public String getAbbreviation()
    {
	return "O";
    }
}   
