/*
  Copyright 2002 Massachusetts Institute of Technology
    
  Permission to use, copy, modify, and distribute this program for any
  purpose and without fee is hereby granted, provided that this
  copyright and permission notice appear on all copies and supporting
  documentation, the name of M.I.T. not be used in advertising or
  publicity pertaining to distribution of the program without specific
  prior permission, and notice be given in supporting documentation that
  copying and distribution is by permission of M.I.T.  M.I.T. makes no
  representations about the suitability of this software for any
  purpose.  It is provided "as is" without express or implied warranty.
*/
package sdsi;

import java.security.*;
import sdsi.sexp.*;

/**
   @author Alexander Morcos, Sameer Ajmani
**/
abstract public class Op extends SDSIObject implements SequenceItem {
    /** Creates a new Op from a S-expression list.
	@exception SexpParseException if the list is not a correctly
	formatted Op.*/
    protected Op(SexpList l) throws SexpParseException
    {
	super(l);
    }
    public static Op create(SexpList l) throws SexpParseException
    {
	if (!l.getType().equals("do"))
	    throw new SexpParseException("Not an Op");
	if ((l.size() < 2) || !(l.elementAt(1) instanceof SexpString))
	    throw new SexpParseException("Op type not specified");
	String opcode = ((SexpString)l.elementAt(1)).stringContent();
	if (opcode.equals(HashOp.OPCODE))
	    return new HashOp(l);
	if (opcode.equals(SkipOp.OPCODE))
	    return new SkipOp(l);
	if (opcode.equals(StopOp.OPCODE))
	    return new StopOp(l);
	throw new SexpParseException("Not a recognized Op");
    }
    public String getOpcode()
    {
	return ((SexpString)srep.elementAt(1)).stringContent();
    }
    public String getType()
    {
	return "Op";
    }
    public String getAbbreviation()
    {
	return ",";
    }
    public String toShortString()
    {
	//assumes its short enough
	return this.toReadableString(20);
    }
}
