/*
  Copyright 2002 Massachusetts Institute of Technology
    
  Permission to use, copy, modify, and distribute this program for any
  purpose and without fee is hereby granted, provided that this
  copyright and permission notice appear on all copies and supporting
  documentation, the name of M.I.T. not be used in advertising or
  publicity pertaining to distribution of the program without specific
  prior permission, and notice be given in supporting documentation that
  copying and distribution is by permission of M.I.T.  M.I.T. makes no
  representations about the suitability of this software for any
  purpose.  It is provided "as is" without express or implied warranty.
*/
package sdsi;

import sdsi.sexp.*;
import java.security.NoSuchAlgorithmException;

/**
   @author Alexander Morcos, Sameer Ajmani
**/
public abstract class SDSIPrincipal extends SDSIObject implements Subject {
    public SDSIPrincipal()
    {
    }
    public SDSIPrincipal(SexpList l)
    {
	super(l);
    }
    public boolean sameAs(Object object)
    {
	return (object instanceof SDSIPrincipal)
	    && this.samePrincipalAs((SDSIPrincipal)object);
    }
    public boolean samePrincipalAs(SDSIPrincipal p)
    {
	if (this.getClass().equals(p.getClass())) return this.equals(p);

	if (p instanceof Hash) { // this is a key
	    try {
		Hash thatHash = (Hash)p;
		Hash thisHash = new Hash(thatHash.getHashID(), this);
		return thisHash.equals(thatHash);
	    } catch (NoSuchAlgorithmException e) {
		return false; // FIXME: Silent failure!
	    }
	} else if (this instanceof Hash) { // p is a key
	    try {
		Hash thisHash = (Hash)this;
		Hash thatHash = new Hash(thisHash.getHashID(), p);
		return thisHash.equals(thatHash);
	    } catch (NoSuchAlgorithmException e) {
		return false; // FIXME: Silent failure!
	    }
	}

	return false;
    }
}  
