/*
  Copyright 2002 Massachusetts Institute of Technology
    
  Permission to use, copy, modify, and distribute this program for any
  purpose and without fee is hereby granted, provided that this
  copyright and permission notice appear on all copies and supporting
  documentation, the name of M.I.T. not be used in advertising or
  publicity pertaining to distribution of the program without specific
  prior permission, and notice be given in supporting documentation that
  copying and distribution is by permission of M.I.T.  M.I.T. makes no
  representations about the suitability of this software for any
  purpose.  It is provided "as is" without express or implied warranty.
*/
package sdsi;

import sdsi.sexp.*;
import java.security.*;

/**
   @author Alexander Morcos, Sameer Ajmani
**/
public class SDSIPrivateKey extends SDSIObject implements PrivateKey {
   
  SDSIPrivateKey() {}
  
  /** Creates a new Private Key from a S-expression list.
      @exception SexpParseException if the list is not a correctly
      formatted Private Key.*/
  public SDSIPrivateKey(SexpList l) throws SexpParseException{
    super(l);
     if (!l.getType().equals("private-key"))
      throw new SexpParseException("Not a private key");
  }

  public static SDSIPrivateKey create(SexpList l) throws SexpParseException, SDSIException {
    if ((l.size() < 2) || !(l.elementAt(1) instanceof SexpList))
      throw new SexpParseException("Incorrectly formatted SDSI Private Key");
    String alg = ((SexpList)l.elementAt(1)).getType();
    if (alg.equals("rsa-pkcs1-md5") || alg.equals("rsa-pkcs1-sha1"))
      return new SDSIRSAPrivateKey(l);
    else
      throw new SDSIException("Unknown Public-key algorithm for private key");
  }

  public String getAlgorithm() {
      return "Unknown";
  }
  public String getFormat() {  //we can implement these later if desired
    return null;
  }
  public byte[] getEncoded() {
    return null;
  }
  public String getURI() { //here we assume only one uri
    int numElements = srep.size();
    Sexp lastElement = srep.elementAt(numElements - 1);
    if (lastElement instanceof SexpString)
      return ((SexpString)lastElement).stringContent();
    else
      return null;
  }
  public String getType() {
    return "Private Key";
  }
  public String toShortString() {
    return "Private Key";
  }
    public String getAbbreviation()
    {
	return "k";
    }

}
