/*
  Copyright 2002 Massachusetts Institute of Technology
    
  Permission to use, copy, modify, and distribute this program for any
  purpose and without fee is hereby granted, provided that this
  copyright and permission notice appear on all copies and supporting
  documentation, the name of M.I.T. not be used in advertising or
  publicity pertaining to distribution of the program without specific
  prior permission, and notice be given in supporting documentation that
  copying and distribution is by permission of M.I.T.  M.I.T. makes no
  representations about the suitability of this software for any
  purpose.  It is provided "as is" without express or implied warranty.
*/
package sdsi;

import sdsi.sexp.*;
import java.util.*;

/**
   @author Alexander Morcos, Sameer Ajmani
**/
public class Sequence extends SDSIObject {
  
    SDSIObject[] members;

    public String getAbbreviation()
    {
	return "Q";
    }

    public boolean sameAs(Object object)
    {
	if (object instanceof Sequence) {
	    Sequence that = (Sequence)object;
	    if (this.members.length != that.members.length) return false;
	    for (int i = 0; i < members.length; i++)
		if (!this.members[i].sameAs(that.members[i]))
		    return false;
	    return true;
	}
	return false;
    }
  
    public Sequence(SexpList l) throws SexpParseException{
	super(l); 
	Sexp[] s_members = l.arrayOfElements();
	members = new SDSIObject[s_members.length - 1];
	for (int i = 0;i < members.length; i++) {
	    if (s_members[i+1] instanceof SexpList) {
		members[i]=SDSIObject.principalParse
		    ((SexpList)s_members[i+1], null);
		if (!(members[i] instanceof Cert)
		    && !(members[i] instanceof SDSIPublicKey)
		    && !(members[i] instanceof Op)
		    && !(members[i] instanceof SDSISignature))
		    throw new SexpParseException
			("Sequence should only contain: "
			 +"Public Keys, Signatures, Certs, and Ops");
	    } else
		throw new SexpParseException("Incorrect formatted sequence: "
					     +"contains a SexpString");
	}
    }

    static public Sequence createFrom(SequenceItem[] objects)
	throws SexpParseException
    {
	Sexp[] sexps = new Sexp[objects.length+1];
	sexps[0] = new SexpString("sequence");
	for (int i = 0; i < objects.length; i++)
	    sexps[i+1] = objects[i].getSrep();

	return new Sequence(new SexpList(sexps));
    }

    public SDSIObject[] members() {
	return members;
    }
    public int count() {
	return members.length;
    }
    public String getType() {
	return "Sequence";
    }
    public String toShortString() {
	return "Sequence: " + members.length + " components";
    }
}
